@@ -55,7 +55,10 @@ def vect_batch(batch, mask_prob, one_in_middle):
     x = np.concatenate(batch, axis=0)
     y = x.copy()
 
-    x, mask = mask_data(x, mask_prob, one_in_middle)
+    if mask_prob > 1e-6:
+        x, mask = mask_data(x, mask_prob, one_in_middle)
+    else:
+        mask = np.ones(x.shape, dtype='bool')
 
     return tf.one_hot(x, len(AA_DICT)), tf.one_hot(y, len(AA_DICT)), mask
 
